# Test

* [1 Introduction](#1-Introduction)
* [2 How to Contribute](#2-How-to-Contribute)

## 1. Introduction
When you commit code to your repository, you can continuously build and test the code to make sure that the commit doesn't introduce errors.
Anytime you submit a pull request, make sure you include tests, and try them using ```pytest``` in this directory.

## 2.How-to-Contribute

###  2.1 Arena-Test
Create a new test class inheriting from the 'Testmodelcore' class as shown in the [Agent_test](https://github.com/ClementineDomine/NeuralPlayground/blob/main/neuralplayground/tests/agent_test.py).

###  2.2 Agent-Test
Create a new test class inheriting from the 'TestSimple2D' class as shown in [Arena_test](https://github.com/ClementineDomine/NeuralPlayground/blob/main/neuralplayground/tests/arena_exp_test.py).
